@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2018 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -122,7 +122,7 @@ void AlbumView::refresh()
         return;
     }
     for (const QString &lang: engine->getLangs()) {
-        QFile::remove(cacheFileName(Covers::fixArtist(currentSong.albumArtist()), currentSong.album, engine->getPrefix(lang), false));
+        QFile::remove(cacheFileName(Covers::fixArtist(currentSong.albumArtistOrComposer()), currentSong.album, engine->getPrefix(lang), false));
     }
     update(currentSong, true);
 }
@@ -142,14 +142,14 @@ void AlbumView::update(const Song &song, bool force)
         return;
     }
 
-    if (song.isEmpty() || song.albumArtist().isEmpty() || song.album.isEmpty()) {
+    if (song.isEmpty() || song.albumArtistOrComposer().isEmpty() || song.album.isEmpty()) {
         currentSong=song;
         clearDetails();
         abort();
         return;
     }
 
-    if (force || song.albumArtist()!=currentSong.albumArtist() || song.album!=currentSong.album) {
+    if (force || song.albumArtistOrComposer()!=currentSong.albumArtistOrComposer() || song.album!=currentSong.album) {
         currentSong=song;
         currentArtist=currentSong.basicArtist();
         abort();
@@ -223,7 +223,7 @@ void AlbumView::getTrackListing()
 
                 trackList+=QLatin1String("<tr><td align='right'>")+QString::number(s.track)+
                            QLatin1String("</td><td><a href=\"")+u.toString()+QLatin1String("\">") +
-                           (s.sameMetadata(currentSong) ? "<b>"+s.displayTitle()+"</b>" : s.displayTitle())+
+                           ((s.albumartist==currentSong.albumartist && s.album==currentSong.album && s.title==currentSong.title) ? "<b>"+s.displayTitle()+"</b>" : s.displayTitle())+
                            QLatin1String("</a></td></tr>");
             } else {
                 trackList+=QLatin1String("<tr><td align='right'>")+QString::number(s.track)+
@@ -243,7 +243,7 @@ void AlbumView::getDetails()
     engine->cancel();
     for (const QString &lang: engine->getLangs()) {
         QString prefix=engine->getPrefix(lang);
-        QString cachedFile=cacheFileName(Covers::fixArtist(currentSong.albumArtist()), currentSong.album, prefix, false);
+        QString cachedFile=cacheFileName(Covers::fixArtist(currentSong.albumArtistOrComposer()), currentSong.album, prefix, false);
         if (QFile::exists(cachedFile)) {
             QFile f(cachedFile);
             QtIOCompressor compressor(&f);
@@ -259,7 +259,7 @@ void AlbumView::getDetails()
             }
         }
     }
-    engine->search(QStringList() << currentSong.albumArtist() << currentSong.album, ContextEngine::Album);
+    engine->search(QStringList() << currentSong.albumArtistOrComposer() << currentSong.album, ContextEngine::Album);
 }
 
 void AlbumView::coverRetrieved(const Song &s, const QImage &img, const QString &file)
@@ -300,7 +300,7 @@ void AlbumView::searchResponse(const QString &resp, const QString &lang)
     if (!resp.isEmpty()) {
         details=engine->translateLinks(resp);
         if (!lang.isEmpty()) {
-            QFile f(cacheFileName(Covers::fixArtist(currentSong.albumArtist()), currentSong.album, lang, true));
+            QFile f(cacheFileName(Covers::fixArtist(currentSong.albumArtistOrComposer()), currentSong.album, lang, true));
             QtIOCompressor compressor(&f);
             compressor.setStreamFormat(QtIOCompressor::GzipFormat);
             if (compressor.open(QIODevice::WriteOnly)) {
