@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2018 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -43,6 +43,7 @@
 #include <QMenu>
 #include <QTimer>
 #include <QDesktopServices>
+#include <algorithm>
 
 static const char *constNameKey="name";
 
@@ -156,7 +157,7 @@ void ArtistView::update(const Song &s, bool force)
     }
 
     Song song=s;
-    song.artist=song.basicArtist();
+    song.artist=song.basicArtist(true);
     bool artistChanged=song.artist!=currentSong.artist;
 
     if (artistChanged) {
@@ -199,7 +200,7 @@ void ArtistView::update(const Song &s, bool force)
 const QList<LibraryDb::Album> & ArtistView::getArtistAlbums()
 {
     if (artistAlbums.isEmpty() && !currentSong.isEmpty()) {
-        artistAlbums=MpdLibraryModel::self()->getArtistAlbums(currentSong.artist);
+        artistAlbums=MpdLibraryModel::self()->getArtistOrComposerAlbums(currentSong.artist);
     }
     return artistAlbums;
 }
@@ -416,7 +417,7 @@ QStringList ArtistView::parseSimilarResponse(const QByteArray &resp)
         }
     }
 
-    qSort(artists);
+    std::sort(artists.begin(), artists.end());
     return artists;
 }
 
