@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2018 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -95,7 +95,7 @@ public:
             f.setBold(true);
         }
         QFontMetrics fm(f);
-        if (fm.width(txt)>rect().width()) {
+        if (fm.horizontalAdvance(txt)>rect().width()) {
             txt=fm.elidedText(txt, isRightToLeft() ? Qt::ElideLeft : Qt::ElideRight, rect().width());
         }
 
@@ -279,20 +279,9 @@ ContextWidget::ContextWidget(QWidget *parent)
     connect(artist, SIGNAL(findAlbum(QString,QString)), this, SIGNAL(findAlbum(QString,QString)));
     connect(album, SIGNAL(playSong(QString)), this, SIGNAL(playSong(QString)));
     readConfig();
-    setZoom();
     setWide(true);
 }
 
-void ContextWidget::setZoom()
-{
-    int zoom=Settings::self()->contextZoom();
-    if (zoom) {
-        artist->setZoom(zoom);
-        album->setZoom(zoom);
-        song->setZoom(zoom);
-    }
-}
-
 void ContextWidget::setWide(bool w)
 {
     if (w==isWide) {
@@ -440,7 +429,6 @@ void ContextWidget::readConfig()
 
 void ContextWidget::saveConfig()
 {
-    Settings::self()->saveContextZoom(artist->getZoom());
     if (viewSelector) {
         Settings::self()->saveContextSlimPage(viewSelector->itemData(viewSelector->currentIndex()).toString());
     }
@@ -516,7 +504,7 @@ void ContextWidget::paintEvent(QPaintEvent *e)
     QRect r(rect());
 
     if (darkBackground) {
-        p.fillRect(r, palette().background().color());
+        p.fillRect(r, palette().window().color());
     } else {
         QColor col = palette().windowText().color();
         col.setAlphaF(0.15);
@@ -662,22 +650,6 @@ void ContextWidget::update(const Song &s)
     }
 }
 
-bool ContextWidget::eventFilter(QObject *o, QEvent *e)
-{
-    if (QEvent::Wheel==e->type()) {
-        QWheelEvent *we=static_cast<QWheelEvent *>(e);
-        if (Qt::ControlModifier==we->modifiers()) {
-            int numDegrees = static_cast<QWheelEvent *>(e)->delta() / 8;
-            int numSteps = numDegrees / 15;
-            artist->setZoom(numSteps);
-            album->setZoom(numSteps);
-            song->setZoom(numSteps);
-            return true;
-        }
-    }
-    return QObject::eventFilter(o, e);
-}
-
 void ContextWidget::cancel()
 {
     if (job) {
