@@ -28,6 +28,8 @@
 #include "upowerinterface.h"
 #include "login1interface.h"
 #include "mpd-interface/mpdstatus.h"
+#include <QGuiApplication>
+#include <QString>
 
 GLOBAL_STATIC(PowerManagement, instance)
 
@@ -38,7 +40,7 @@ PowerManagement::PowerManagement()
     policy = new OrgKdeSolidPowerManagementPolicyAgentInterface(OrgKdeSolidPowerManagementPolicyAgentInterface::staticInterfaceName(),
                                                                 QLatin1String("/org/kde/Solid/PowerManagement/PolicyAgent"),
                                                                 QDBusConnection::sessionBus(), this);
-    inhibit = new OrgFreedesktopPowerManagementInhibitInterface(OrgFreedesktopPowerManagementInhibitInterface::staticInterfaceName(),
+    inhibit = new OrgFreedesktopPowerManagementInhibitInterface("org.freedesktop.PowerManagement",
                                                                 QLatin1String("/org/freedesktop/PowerManagement/Inhibit"),
                                                                 QDBusConnection::sessionBus(), this);
     upower = new OrgFreedesktopUPowerInterface(OrgFreedesktopUPowerInterface::staticInterfaceName(),
@@ -69,33 +71,46 @@ void PowerManagement::setInhibitSuspend(bool i)
 
 void PowerManagement::beginSuppressingSleep()
 {
-    if (-1!=cookie) {
+    if (-1!=cookie || descriptor.isValid()) {
         return;
     }
+
     QString reason=tr("Cantata is playing a track");
     QDBusReply<uint> reply;
     if (policy->isValid()) {
-        reply = policy->AddInhibition((uint)1, QCoreApplication::applicationName(), reason);
+        reply = policy->AddInhibition((uint)1, QGuiApplication::applicationDisplayName(), reason);
     } else {
         // Fallback to the fd.o Inhibit interface
-        reply = inhibit->Inhibit(QCoreApplication::applicationName(), reason);
+        reply = inhibit->Inhibit(QGuiApplication::applicationDisplayName(), reason);
     }
     cookie=reply.isValid() ? reply : -1;
+
+    QString types=QStringLiteral("sleep");
+    QString mode=QStringLiteral("block");
+    QDBusPendingReply<QDBusUnixFileDescriptor> futureReply;
+    futureReply = login1->Inhibit(types, QGuiApplication::applicationDisplayName(), reason, mode);
+    futureReply.waitForFinished();
+    if (futureReply.isValid()) {
+        descriptor=futureReply.value();
+    }
 }
 
 void PowerManagement::stopSuppressingSleep()
 {
-    if (-1==cookie) {
-        return;
+    if (-1!=cookie) {
+        if (policy->isValid()) {
+            policy->ReleaseInhibition(cookie);
+        } else {
+            // Fallback to the fd.o Inhibit interface
+            inhibit->UnInhibit(cookie);
+        }
+        cookie=-1;
     }
 
-    if (policy->isValid()) {
-        policy->ReleaseInhibition(cookie);
-    } else {
-        // Fallback to the fd.o Inhibit interface
-        inhibit->UnInhibit(cookie);
+    if (descriptor.isValid()) {
+        QDBusUnixFileDescriptor invalidDescriptor;
+        descriptor.swap(invalidDescriptor);
     }
-    cookie=-1;
 }
 
 void PowerManagement::mpdStatusUpdated()
