@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2014 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -22,13 +22,12 @@
  */
 
 #include "albumdetailsdialog.h"
-#include "support/localize.h"
 #include "audiocddevice.h"
-#include "models/musiclibrarymodel.h"
 #include "models/musiclibraryitemsong.h"
 #include "support/messagebox.h"
 #include "support/inputdialog.h"
 #include "models/devicesmodel.h"
+#include "models/mpdlibrarymodel.h"
 #include "cdalbum.h"
 #include "widgets/icons.h"
 #include "gui/coverdialog.h"
@@ -38,6 +37,7 @@
 #include <QStyledItemDelegate>
 #include <QMouseEvent>
 #include <QSpinBox>
+#include <algorithm>
 
 enum Columns {
     COL_TRACK,
@@ -51,7 +51,7 @@ public:
     EditorDelegate(QObject *parent=0) : BasicItemDelegate(parent) { }
 
     QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const {
-        Q_UNUSED(option);
+        Q_UNUSED(option)
         if (COL_TRACK==index.column()) {
             QSpinBox *editor = new QSpinBox(parent);
             editor->setMinimum(0);
@@ -83,7 +83,7 @@ public:
     }
 
     void updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &index) const {
-        Q_UNUSED(index);
+        Q_UNUSED(index)
         editor->setGeometry(option.rect);
     }
 };
@@ -101,7 +101,7 @@ AlbumDetailsDialog::AlbumDetailsDialog(QWidget *parent)
 {
     iCount++;
     setButtons(User1|Ok|Cancel);
-    setCaption(i18n("Audio CD"));
+    setCaption(tr("Audio CD"));
     setAttribute(Qt::WA_DeleteOnClose);
 
     QWidget *mainWidet = new QWidget(this);
@@ -113,7 +113,7 @@ AlbumDetailsDialog::AlbumDetailsDialog(QWidget *parent)
     QSet<QString> composers;
     QSet<QString> albums;
     QSet<QString> genres;
-    MusicLibraryModel::self()->getDetails(artists, albumArtists, composers, albums, genres);
+    MpdLibraryModel::self()->getDetails(artists, albumArtists, composers, albums, genres);
 
     QStringList strings=albumArtists.toList();
     strings.sort();
@@ -136,12 +136,12 @@ AlbumDetailsDialog::AlbumDetailsDialog(QWidget *parent)
     genre->insertItems(0, strings);
 
     QMenu *toolsMenu=new QMenu(this);
-    toolsMenu->addAction(i18n("Apply \"Various Artists\" Workaround"), this, SLOT(applyVa()));
-    toolsMenu->addAction(i18n("Revert \"Various Artists\" Workaround"), this, SLOT(revertVa()));
-    toolsMenu->addAction(i18n("Capitalize"), this, SLOT(capitalise()));
-    toolsMenu->addAction(i18n("Adjust Track Numbers"), this, SLOT(adjustTrackNumbers()));
+    toolsMenu->addAction(tr("Apply \"Various Artists\" Workaround"), this, SLOT(applyVa()));
+    toolsMenu->addAction(tr("Revert \"Various Artists\" Workaround"), this, SLOT(revertVa()));
+    toolsMenu->addAction(tr("Capitalize"), this, SLOT(capitalise()));
+    toolsMenu->addAction(tr("Adjust Track Numbers"), this, SLOT(adjustTrackNumbers()));
     setButtonMenu(User1, toolsMenu, InstantPopup);
-    setButtonGuiItem(User1, GuiItem(i18n("Tools"), "tools-wizard"));
+    setButtonGuiItem(User1, GuiItem(tr("Tools"), "tools-wizard"));
     connect(singleArtist, SIGNAL(toggled(bool)), SLOT(hideArtistColumn(bool)));
     resize(600, 600);
 
@@ -172,12 +172,12 @@ void AlbumDetailsDialog::show(AudioCdDevice *dev)
     artists.insert(dev->albumArtist());
 
     QList<Song> songs;
-    foreach (const MusicLibraryItem *i, dev->childItems()) {
+    for (const MusicLibraryItem *i: dev->childItems()) {
         songs.append(static_cast<const MusicLibraryItemSong *>(i)->song());
     }
-    qSort(songs);
+    std::sort(songs.begin(), songs.end());
 
-    foreach (const Song &s, songs) {
+    for (const Song &s: songs) {
         QTreeWidgetItem *item=new QTreeWidgetItem(tracks);
         update(item, s);
         artists.insert(s.artist);
@@ -229,11 +229,11 @@ void AlbumDetailsDialog::hideArtistColumn(bool hide)
 
 void AlbumDetailsDialog::applyVa()
 {
-    if (MessageBox::No==MessageBox::questionYesNo(this, i18n("Apply \"Various Artists\" workaround?")+
-                                                        QLatin1String("<br/><hr/><br/>")+
-                                                        i18n("<i>This will set 'Album artist' and 'Artist' to "
+    if (MessageBox::No==MessageBox::questionYesNo(this, tr("Apply \"Various Artists\" workaround?")+
+                                                        QLatin1String("\n\n")+
+                                                        tr("This will set 'Album artist' and 'Artist' to "
                                                              "\"Various Artists\", and set 'Title' to "
-                                                             "\"TrackArtist - TrackTitle\"</i>"), i18n("Apply \"Various Artists\" Workaround"),
+                                                             "\"TrackArtist - TrackTitle\""), tr("Apply \"Various Artists\" Workaround"),
                                                   StdGuiItem::apply(), StdGuiItem::cancel())) {
         return;
     }
@@ -250,15 +250,15 @@ void AlbumDetailsDialog::applyVa()
 
 void AlbumDetailsDialog::revertVa()
 {
-    if (MessageBox::No==MessageBox::questionYesNo(this, i18n("Revert \"Various Artists\" workaround")+
-                                                        QLatin1String("<br/><hr/><br/>")+
-                                                        i18n("<i>Where the 'Album artist' is the same as 'Artist' "
+    if (MessageBox::No==MessageBox::questionYesNo(this, tr("Revert \"Various Artists\" workaround?")+
+                                                        QLatin1String("\n\n")+
+                                                        tr("Where the 'Album artist' is the same as 'Artist' "
                                                              "and the 'Title' is of the format \"TrackArtist - TrackTitle\", "
                                                              "'Artist' will be taken from 'Title' and 'Title' itself will be "
-                                                             "set to just the title. e.g. <br/><br/>"
+                                                             "set to just the title. e.g. \n"
                                                              "If 'Title' is \"Wibble - Wobble\", then 'Artist' will be set to "
-                                                             "\"Wibble\" and 'Title' will be set to \"Wobble\"</i>"), i18n("Revert \"Various Artists\" Workaround"),
-                                                  GuiItem(i18n("Revert")), StdGuiItem::cancel())) {
+                                                             "\"Wibble\" and 'Title' will be set to \"Wobble\""), tr("Revert \"Various Artists\" Workaround"),
+                                                  GuiItem(tr("Revert")), StdGuiItem::cancel())) {
         return;
     }
 
@@ -274,8 +274,8 @@ void AlbumDetailsDialog::revertVa()
 
 void AlbumDetailsDialog::capitalise()
 {
-    if (MessageBox::No==MessageBox::questionYesNo(this, i18n("Capitalize the first letter of 'Title', 'Artist', 'Album artist', and 'Album'"),
-                                                  i18n("Capitalize"), GuiItem(i18n("Capitalize")), StdGuiItem::cancel())) {
+    if (MessageBox::No==MessageBox::questionYesNo(this, tr("Capitalize the first letter of 'Title', 'Artist', 'Album artist', and 'Album'?"),
+                                                  tr("Capitalize"), GuiItem(tr("Capitalize")), StdGuiItem::cancel())) {
         return;
     }
 
@@ -292,7 +292,7 @@ void AlbumDetailsDialog::capitalise()
 void AlbumDetailsDialog::adjustTrackNumbers()
 {
     bool ok=false;
-    int adj=InputDialog::getInteger(i18n("Adjust Track Numbers"), i18n("Adjust track number by:"), 0, -500, 500, 1, 10, &ok, this);
+    int adj=InputDialog::getInteger(tr("Adjust Track Numbers"), tr("Adjust track number by:"), 0, -500, 500, 1, 10, &ok, this);
 
     if (!ok || 0==adj) {
         return;
@@ -318,7 +318,7 @@ Song AlbumDetailsDialog::toSong(QTreeWidgetItem *i, const CdAlbum &album)
     Song s;
     s.albumartist=album.artist;
     s.album=album.name;
-    s.genre=album.genre;
+    s.genres[0]=album.genre;
     s.year=album.year;
     s.disc=album.disc;
     s.artist=singleArtist->isChecked() ? s.albumartist : i->text(COL_ARTIST);
@@ -365,7 +365,7 @@ void AlbumDetailsDialog::update(QTreeWidgetItem *i, const Song &s)
 void AlbumDetailsDialog::setCover()
 {
     int iconSize=cover->size().width()<=128 ? 128 : 256;
-    cover->setPixmap(Icons::self()->albumIcon.pixmap(iconSize, iconSize).scaled(cover->size(), Qt::IgnoreAspectRatio, Qt::SmoothTransformation));
+    cover->setPixmap(Icons::self()->albumIcon(iconSize).pixmap(iconSize, iconSize).scaled(cover->size(), Qt::IgnoreAspectRatio, Qt::SmoothTransformation));
 }
 
 bool AlbumDetailsDialog::eventFilter(QObject *object, QEvent *event)
@@ -404,3 +404,5 @@ void AlbumDetailsDialog::coverSelected(const QImage &img, const QString &fileNam
         cover->setPixmap(QPixmap::fromImage(coverImage.img.scaled(cover->size(), Qt::IgnoreAspectRatio, Qt::SmoothTransformation)));
     }
 }
+
+#include "moc_albumdetailsdialog.cpp"
