@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2018 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -172,7 +172,7 @@ void MusicScanner::scanFolder(MusicLibraryItemRoot *library, const QString &topL
                 song.fillEmptyFields();
                 song.populateSorts();
                 song.size=info.size();
-                if (!artistItem || song.artistOrComposer()!=artistItem->data()) {
+                if (!artistItem || song.albumArtistOrComposer()!=artistItem->data()) {
                     artistItem = library->artist(song);
                 }
                 if (!albumItem || albumItem->parentItem()!=artistItem || song.albumName()!=albumItem->data()) {
@@ -289,7 +289,7 @@ void FsDevice::writeOpts(const QString &fileName, const DeviceOptions &opts, boo
             if (opts.scheme!=def.scheme) {
                 out << constMusicFilenameSchemeKey << '=' << opts.scheme << '\n';
             }
-            if (opts.scheme!=def.scheme) {
+            if (opts.vfatSafe!=def.vfatSafe) {
                 out << constVfatSafeKey << '=' << toString(opts.vfatSafe) << '\n';
             }
             if (opts.asciiOnly!=def.asciiOnly) {
