@@ -23,51 +23,41 @@
 
 #include "synccollectionwidget.h"
 #include "widgets/treeview.h"
-#include "models/musiclibraryproxymodel.h"
+#include "widgets/toolbutton.h"
+#include "widgets/icons.h"
 #include "models/musiclibraryitemartist.h"
 #include "models/musiclibraryitemalbum.h"
 #include "models/musiclibraryitemsong.h"
 #include "support/icon.h"
-#include "support/localize.h"
 #include "support/actioncollection.h"
 #include <QTimer>
 #include <QAction>
+#include <algorithm>
 
-SyncCollectionWidget::SyncCollectionWidget(QWidget *parent, const QString &title, const QString &action, bool showCovers)
+SyncCollectionWidget::SyncCollectionWidget(QWidget *parent, const QString &title)
     : QWidget(parent)
     , performedSearch(false)
-    , searchTimer(0)
+    , searchTimer(nullptr)
 {
     setupUi(this);
     titleLabel->setText(title);
-    button->setText(action);
-    button->setEnabled(false);
+    cfgButton->setIcon(Icons::self()->configureIcon);
+    connect(cfgButton, SIGNAL(clicked(bool)), SIGNAL(configure()));
 
-    model=new MusicLibraryModel(this, false, true);
-    proxy=new MusicLibraryProxyModel(this);
-    model->setUseAlbumImages(showCovers);
-    proxy->setSourceModel(model);
-    tree->setModel(proxy);
+    proxy.setSourceModel(&model);
+    tree->setModel(&proxy);
     tree->setPageDefaults();
     tree->setUseSimpleDelegate();
     search->setText(QString());
-    search->setPlaceholderText(i18n("Search"));
-    connect(proxy, SIGNAL(dataChanged(QModelIndex,QModelIndex)), this, SLOT(dataChanged(QModelIndex,QModelIndex)));
-    connect(model, SIGNAL(checkedSongs(QSet<Song>)), this, SLOT(songsChecked(QSet<Song>)));
-    connect(button, SIGNAL(clicked()), SLOT(copySongs()));
+    search->setPlaceholderText(tr("Search"));
+    connect(&proxy, SIGNAL(dataChanged(QModelIndex,QModelIndex)), this, SLOT(dataChanged(QModelIndex,QModelIndex)));
     connect(search, SIGNAL(returnPressed()), this, SLOT(delaySearchItems()));
     connect(search, SIGNAL(textChanged(const QString)), this, SLOT(delaySearchItems()));
 
-    copyAction=new Action(action, this);
-    connect(copyAction, SIGNAL(triggered(bool)), SLOT(copySongs()));
-    checkAction=new Action(i18n("Check Items"), this);
-    connect(checkAction, SIGNAL(triggered(bool)), SLOT(checkItems()));
-    unCheckAction=new Action(i18n("Uncheck Items"), this);
-    connect(unCheckAction, SIGNAL(triggered(bool)), SLOT(unCheckItems()));
-    tree->addAction(copyAction);
-    QAction *sep=new QAction(this);
-    sep->setSeparator(true);
-    tree->addAction(sep);
+    checkAction=new Action(tr("Check Items"), this);
+    connect(checkAction, SIGNAL(triggered()), SLOT(checkItems()));
+    unCheckAction=new Action(tr("Uncheck Items"), this);
+    connect(unCheckAction, SIGNAL(triggered()), SLOT(unCheckItems()));
     tree->addAction(checkAction);
     tree->addAction(unCheckAction);
     tree->setContextMenuPolicy(Qt::ActionsContextMenu);
@@ -75,31 +65,90 @@ SyncCollectionWidget::SyncCollectionWidget(QWidget *parent, const QString &title
     QAction *expand=ActionCollection::get()->action("expandall");
     QAction *collapse=ActionCollection::get()->action("collapseall");
     if (expand && collapse) {
-        sep=new QAction(this);
-        sep->setSeparator(true);
-        tree->addAction(sep);
         tree->addAction(expand);
         tree->addAction(collapse);
         addAction(expand);
         addAction(collapse);
-        connect(expand, SIGNAL(triggered(bool)), this, SLOT(expandAll()));
-        connect(collapse, SIGNAL(triggered(bool)), this, SLOT(collapseAll()));
+        connect(expand, SIGNAL(triggered()), this, SLOT(expandAll()));
+        connect(collapse, SIGNAL(triggered()), this, SLOT(collapseAll()));
     }
 
     connect(tree, SIGNAL(itemsSelected(bool)), checkAction, SLOT(setEnabled(bool)));
     connect(tree, SIGNAL(itemsSelected(bool)), unCheckAction, SLOT(setEnabled(bool)));
     connect(tree, SIGNAL(itemActivated(const QModelIndex &)), this, SLOT(itemActivated(const QModelIndex &)));
     connect(tree, SIGNAL(clicked(const QModelIndex &)),  this, SLOT(itemClicked(const QModelIndex &)));
-    updateStats();
 }
 
 SyncCollectionWidget::~SyncCollectionWidget()
 {
 }
 
-void SyncCollectionWidget::setIcon(const Icon &icon)
+void SyncCollectionWidget::update(const QSet<Song> &songs)
 {
-    tree->setBackgroundImage(icon);
+    model.setSongs(songs);
+}
+
+QList<Song> SyncCollectionWidget::checkedSongs() const
+{
+    QList<Song> songs;
+    for (const Song *s: checked) {
+        songs.append(*s);
+    }
+    std::sort(songs.begin(), songs.end());
+    return songs;
+}
+
+void SyncCollectionWidget::dataChanged(const QModelIndex &tl, const QModelIndex &br)
+{
+    bool haveChecked=numCheckedSongs()>0;
+    QModelIndex firstIndex = proxy.mapToSource(tl);
+    QModelIndex lastIndex = proxy.mapToSource(br);
+    const MusicLibraryItem *item=static_cast<const MusicLibraryItem *>(firstIndex.internalPointer());
+    switch (item->itemType()) {
+    case MusicLibraryItem::Type_Artist:
+        for (int i=firstIndex.row(); i<=lastIndex.row(); ++i) {
+            QModelIndex index=model.index(i, 0, firstIndex.parent());
+            const MusicLibraryItemArtist *artist=static_cast<const MusicLibraryItemArtist *>(index.internalPointer());
+            for (const MusicLibraryItem *alItem: artist->childItems()) {
+                for (const MusicLibraryItem *sItem: static_cast<const MusicLibraryItemContainer *>(alItem)->childItems()) {
+                    songToggled(static_cast<const MusicLibraryItemSong *>(sItem));
+                }
+            }
+        }
+        break;
+    case MusicLibraryItem::Type_Album:
+        for (int i=firstIndex.row(); i<=lastIndex.row(); ++i) {
+            QModelIndex index=model.index(i, 0, firstIndex.parent());
+            const MusicLibraryItemAlbum *album=static_cast<const MusicLibraryItemAlbum *>(index.internalPointer());
+            for (const MusicLibraryItem *sItem: album->childItems()) {
+                songToggled(static_cast<const MusicLibraryItemSong *>(sItem));
+            }
+        }
+        break;
+    case MusicLibraryItem::Type_Song:
+        for (int i=firstIndex.row(); i<=lastIndex.row(); ++i) {
+            QModelIndex index=model.index(i, 0, firstIndex.parent());
+            songToggled(static_cast<MusicLibraryItemSong *>(index.internalPointer()));
+        }
+    default:
+        break;
+    }
+
+    if (haveChecked!=(numCheckedSongs()>0)) {
+        emit selectionChanged();
+    }
+}
+
+void SyncCollectionWidget::songToggled(const MusicLibraryItemSong *song)
+{
+    const Song &s=song->song();
+    if (Qt::Checked==song->checkState()) {
+        checked.insert(&s);
+        spaceRequired+=s.size;
+    } else {
+        checked.remove(&s);
+        spaceRequired-=s.size;
+    }
 }
 
 void SyncCollectionWidget::checkItems()
@@ -120,21 +169,11 @@ void SyncCollectionWidget::checkItems(bool c)
         return;
     }
 
-    foreach (const QModelIndex &idx, selected) {
-        model->setData(proxy->mapToSource(idx), c, Qt::CheckStateRole);
+    for (const QModelIndex &idx: selected) {
+        model.setData(proxy.mapToSource(idx), c, Qt::CheckStateRole);
     }
 }
 
-void SyncCollectionWidget::copySongs()
-{
-    if (checkedSongs.isEmpty()) {
-        return;
-    }
-    QList<Song> songs=checkedSongs.toList();
-    qSort(songs);
-    emit copy(songs);
-}
-
 void SyncCollectionWidget::delaySearchItems()
 {
     if (search->text().trimmed().isEmpty()) {
@@ -159,8 +198,8 @@ void SyncCollectionWidget::delaySearchItems()
 void SyncCollectionWidget::searchItems()
 {
     QString text=search->text().trimmed();
-    proxy->update(text);
-    if (proxy->enabled() && !text.isEmpty()) {
+    proxy.update(text);
+    if (proxy.enabled() && !text.isEmpty()) {
         tree->expandAll();
     }
     performedSearch=true;
@@ -196,82 +235,4 @@ void SyncCollectionWidget::itemActivated(const QModelIndex &index)
     }
 }
 
-void SyncCollectionWidget::songsChecked(const QSet<Song> &songs)
-{
-    checkedSongs=songs;
-    button->setEnabled(!checkedSongs.isEmpty());
-    updateStats();
-}
-
-
-void SyncCollectionWidget::dataChanged(const QModelIndex &tl, const QModelIndex &br)
-{
-    QModelIndex firstIndex = proxy->mapToSource(tl);
-    QModelIndex lastIndex = proxy->mapToSource(br);
-    const MusicLibraryItem *item=static_cast<const MusicLibraryItem *>(firstIndex.internalPointer());
-    switch (item->itemType()) {
-    case MusicLibraryItem::Type_Artist:
-        for (int i=firstIndex.row(); i<=lastIndex.row(); ++i) {
-            QModelIndex index=model->index(i, 0, firstIndex.parent());
-            const MusicLibraryItemArtist *artist=static_cast<const MusicLibraryItemArtist *>(index.internalPointer());
-            foreach (const MusicLibraryItem *alItem, artist->childItems()) {
-                foreach (const MusicLibraryItem *sItem, static_cast<const MusicLibraryItemContainer *>(alItem)->childItems()) {
-                    Song s=static_cast<const MusicLibraryItemSong *>(sItem)->song();
-                    if (Qt::Checked==item->checkState()) {
-                        checkedSongs.insert(s);
-                    } else {
-                        checkedSongs.remove(s);
-                    }
-                }
-            }
-        }
-        break;
-    case MusicLibraryItem::Type_Album:
-        for (int i=firstIndex.row(); i<=lastIndex.row(); ++i) {
-            QModelIndex index=model->index(i, 0, firstIndex.parent());
-            const MusicLibraryItemAlbum *album=static_cast<const MusicLibraryItemAlbum *>(index.internalPointer());
-            foreach (const MusicLibraryItem *sItem, album->childItems()) {
-                Song s=static_cast<const MusicLibraryItemSong *>(sItem)->song();
-                if (Qt::Checked==item->checkState()) {
-                    checkedSongs.insert(s);
-                } else {
-                    checkedSongs.remove(s);
-                }
-            }
-        }
-        break;
-    case MusicLibraryItem::Type_Song:
-        for (int i=firstIndex.row(); i<=lastIndex.row(); ++i) {
-            QModelIndex index=model->index(i, 0, firstIndex.parent());
-            Song s=static_cast<MusicLibraryItemSong *>(index.internalPointer())->song();
-            if (Qt::Checked==item->checkState()) {
-                checkedSongs.insert(s);
-            } else {
-                checkedSongs.remove(s);
-            }
-        }
-    default:
-        break;
-    }
-
-    button->setEnabled(!checkedSongs.isEmpty());
-    updateStats();
-}
-
-void SyncCollectionWidget::updateStats()
-{
-    QSet<QString> artists;
-    QSet<QString> albums;
-
-    foreach (const Song &s, checkedSongs) {
-        artists.insert(s.albumArtist());
-        albums.insert(s.albumArtist()+"--"+s.album);
-    }
-
-    if (checkedSongs.isEmpty()) {
-        selection->setText(i18n("Nothing selected"));
-    } else {
-        selection->setText(i18n("Artists:%1, Albums:%2, Songs:%3", artists.count(), albums.count(), checkedSongs.count()));
-    }
-    copyAction->setEnabled(!checkedSongs.isEmpty());
-}
+#include "moc_synccollectionwidget.cpp"
