@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2018 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -30,8 +30,9 @@
 Application::Application(int &argc, char **argv)
     : QApplication(argc, argv)
 {
+    setApplicationDisplayName(QLatin1String("Cantata"));
     #if QT_VERSION >= 0x050700
-    setDesktopFileName(QLatin1String("cantata.desktop"));
+    setDesktopFileName(QLatin1String("cantata"));
     #endif
 }
 
