@@ -329,12 +329,7 @@ MPDParseUtils::CueSupport Settings::cueSupport()
 
 QStringList Settings::lyricProviders()
 {
-    return cfg.get("lyricProviders", QStringList() << "lyrics.wikia.com" << "lyricstime.com" << "lyricsreg.com"
-                                                   << "lyricsmania.com" << "metrolyrics.com" << "azlyrics.com"
-                                                   << "songlyrics.com" << "elyrics.net" << "lyricsdownload.com"
-                                                   << "lyrics.com" << "lyricsbay.com" << "directlyrics.com"
-                                                   << "loudson.gs" << "teksty.org" << "tekstowo.pl (POLISH)"
-                                                   << "vagalume.uol.com.br" << "vagalume.uol.com.br (PORTUGUESE)");
+    return cfg.get("lyricProviders", QStringList() << "azlyrics.com" << "chartlyrics.com" << "lyrics.wikia.com");
 }
 
 QStringList Settings::wikipediaLangs()
@@ -561,12 +556,12 @@ bool Settings::useCddb()
 #ifdef CDDB_FOUND
 QString Settings::cddbHost()
 {
-    return cfg.get("cddbHost", QString("freedb.freedb.org"));
+    return cfg.get("cddbHost", QString("gnudb.gnudb.org"));
 }
 
 int Settings::cddbPort()
 {
-    return cfg.get("cddbPort", 8880);
+    return cfg.get("cddbPort", 80);
 }
 #endif
 
