@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2018 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -54,6 +54,7 @@
 #include "solid-lite/storagedrive.h"
 #include "solid-lite/storagevolume.h"
 #include "solid-lite/opticaldisc.h"
+#include <algorithm>
 
 #include <QDebug>
 static bool debugIsEnabled=false;
@@ -208,13 +209,13 @@ QList<Song> DevicesModel::songs(const QModelIndexList &indexes, bool playableOnl
                     break;
                 }
 
-                qSort(artists.begin(), artists.end(), MusicLibraryItemArtist::lessThan);
+                std::sort(artists.begin(), artists.end(), MusicLibraryItemArtist::lessThan);
 
                 for (MusicLibraryItem *a: artists) {
                     const MusicLibraryItemContainer *artist=static_cast<const MusicLibraryItemContainer *>(a);
                     // Now sort all albums as they would appear in UI...
                     QList<MusicLibraryItem *> artistAlbums=artist->childItems();
-                    qSort(artistAlbums.begin(), artistAlbums.end(), MusicLibraryItemAlbum::lessThan);
+                    std::sort(artistAlbums.begin(), artistAlbums.end(), MusicLibraryItemAlbum::lessThan);
                     for (MusicLibraryItem *i: artistAlbums) {
                         const MusicLibraryItemContainer *album=static_cast<const MusicLibraryItemContainer *>(i);
                         for (const MusicLibraryItem *song: album->childItems()) {
@@ -231,7 +232,7 @@ QList<Song> DevicesModel::songs(const QModelIndexList &indexes, bool playableOnl
         case MusicLibraryItem::Type_Artist: {
             // First, sort all albums as they would appear in UI...
             QList<MusicLibraryItem *> artistAlbums=static_cast<const MusicLibraryItemContainer *>(item)->childItems();
-            qSort(artistAlbums.begin(), artistAlbums.end(), MusicLibraryItemAlbum::lessThan);
+            std::sort(artistAlbums.begin(), artistAlbums.end(), MusicLibraryItemAlbum::lessThan);
 
             for (MusicLibraryItem *i: artistAlbums) {
                 const MusicLibraryItemContainer *album=static_cast<const MusicLibraryItemContainer *>(i);
@@ -341,7 +342,7 @@ QVariant DevicesModel::data(const QModelIndex &index, int role) const
             }
             if (!dev->isConnected()) {
                 QString sub=dev->subText();
-                return tr("Not Connected")+(sub.isEmpty() ? QString() : (QString(" – ")+sub));
+                return tr("Not Connected")+(sub.isEmpty() ? QString() : (Song::constSep+sub));
             }
             if (Device::AudioCd==dev->devType()) {
                 return dev->subText();
@@ -904,7 +905,7 @@ void DevicesModel::updateItemMenu()
         }
 
         QStringList keys=items.keys();
-        qSort(keys.begin(), keys.end(), lessThan);
+        std::sort(keys.begin(), keys.end(), lessThan);
 
         for (const QString &k: keys) {
             const MusicLibraryItemRoot *d=items[k];
