@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2018 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
  *
  */
 /*
@@ -47,7 +47,7 @@ bool MusicLibraryItemArtist::lessThan(const MusicLibraryItem *a, const MusicLibr
 }
 
 MusicLibraryItemArtist::MusicLibraryItemArtist(const Song &song, MusicLibraryItemContainer *parent)
-    : MusicLibraryItemContainer(song.artistOrComposer(), parent)
+    : MusicLibraryItemContainer(song.albumArtistOrComposer(), parent)
     , m_sortString(song.hasAlbumArtistSort() ? song.albumArtistSort() : QString())
     , m_actualArtist(song.useComposer() ? song.albumArtist() : QString())
 {
