@@ -540,7 +540,8 @@ const MusicLibraryItem * MusicLibraryItemRoot::findSong(const Song &s) const
             MusicLibraryItemAlbum *albumItem = artistItem->album(s, false);
             if (albumItem) {
                 for (const MusicLibraryItem *songItem: albumItem->childItems()) {
-                    if (songItem->data()==s.displayTitle() && static_cast<const MusicLibraryItemSong *>(songItem)->song().track==s.track) {
+                    if (songItem->data()==s.displayTitle() && static_cast<const MusicLibraryItemSong *>(songItem)->song().track==s.track &&
+                        static_cast<const MusicLibraryItemSong *>(songItem)->song().disc==s.disc) {
                         return songItem;
                     }
                 }
