@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2018 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
  *
  */
 /*
@@ -47,6 +47,7 @@
 #ifdef ENABLE_HTTP_SERVER
 #include "http/httpserver.h"
 #endif
+#include <algorithm>
 
 QString PlaylistsModel::headerText(int col)
 {
@@ -476,9 +477,13 @@ QVariant PlaylistsModel::data(const QModelIndex &index, int role) const
         case Cantata::Role_MainText:
             return s->title.isEmpty() ? s->name().isEmpty() ? s->file : s->name() : s->title;
         case Cantata::Role_SubText:
-            return (s->artist.isEmpty() ? QString() : (s->artist+QString(" – ")))+
-                   (s->displayAlbum().isEmpty() ? QString() : (s->displayAlbum()+QString(" – ")))+
+            return (s->artist.isEmpty() ? QString() : (s->artist+Song::constSep))+
+                   (s->displayAlbum().isEmpty() ? QString() : (s->displayAlbum()+Song::constSep))+
                    (s->time>0 ? Utils::formatTime(s->time) : QString());
+        case Cantata::Role_TextColor:
+            if (s->isInvalid()) {
+                return MonoIcon::constRed;
+            }
         default:
             return ActionModel::data(index, role);
         }
@@ -955,7 +960,7 @@ void PlaylistsModel::updateItemMenu(bool create)
             names << p->name;
         }
     }
-    qSort(names.begin(), names.end(), PlaylistsProxyModel::compareNames);
+    std::sort(names.begin(), names.end(), PlaylistsProxyModel::compareNames);
     for (const QString &n: names) {
         itemMenu->addAction(n, this, SLOT(emitAddToExisting()));
     }
