@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2018 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -58,6 +58,7 @@
 #endif
 #include <stdio.h>
 #include <time.h>
+#include <algorithm>
 
 #include <QDebug>
 GLOBAL_STATIC(StreamsModel, instance)
@@ -66,6 +67,7 @@ const QString StreamsModel::constSubDir=QLatin1String("streams");
 const QString StreamsModel::constCacheExt=QLatin1String(".xml.gz");
 const QString StreamsModel::constShoutCastHost=QLatin1String("api.shoutcast.com");
 const QString StreamsModel::constDirbleHost=QLatin1String("api.dirble.com");
+const QString StreamsModel::constCommunityHost=QLatin1String("www.radio-browser.info");
 const QString StreamsModel::constCompressedXmlFile=QLatin1String("streams.xml.gz");
 const QString StreamsModel::constXmlFile=QLatin1String("streams.xml");
 const QString StreamsModel::constSettingsFile=QLatin1String("settings.json");
@@ -121,7 +123,7 @@ QString StreamsModel::Item::modifiedName() const
     if (!cat || !cat->addCatToModifiedName || name.startsWith(cat->name)) {
         return name;
     }
-    return cat->name+QString(" – ")+name;
+    return cat->name+Song::constSep+name;
 }
 
 StreamsModel::CategoryItem * StreamsModel::Item::getTopLevelCategory() const
@@ -1515,7 +1517,7 @@ QList<StreamsModel::Item *> StreamsModel::parseListenLiveResponse(QIODevice *dev
                 }
             } else if ("</tr>"==line) {
                 if (entry.streams.count()) {
-                    qSort(entry.streams);
+                    std::sort(entry.streams.begin(), entry.streams.end());
                     QString name;
                     QString url=entry.streams.at(0).url;
 
@@ -1656,6 +1658,29 @@ QList<StreamsModel::Item *> StreamsModel::parseDirbleStations(QIODevice *dev, Ca
     return newItems;
 }
 
+QList<StreamsModel::Item *> StreamsModel::parseCommunityStations(QIODevice *dev, CategoryItem *cat)
+{
+    QList<Item *> newItems;
+    QVariantList data=QJsonDocument::fromJson(dev->readAll()).toVariant().toList();
+
+    QSet<QString> added;
+    for (const QVariant &d: data) {
+        QVariantMap map = d.toMap();
+        QString name=map["name"].toString().trimmed().simplified();
+        if (!name.isEmpty()) {
+            QString url=map["url"].toString().trimmed().simplified();
+
+            if (!url.isEmpty() && !added.contains(url)) {
+                added.insert(url);
+                QString bitrate=map["bitrate"].toString().trimmed().simplified();
+                QString codec=map["codec"].toString().trimmed().simplified();
+                newItems.append(new Item(url, name, cat, bitrate.isEmpty() ? codec : (bitrate + " kbps" + (codec.isEmpty() ? "" : (", "+codec)))));
+            }
+        }
+    }
+    return newItems;
+}
+
 StreamsModel::Item * StreamsModel::parseRadioTimeEntry(QXmlStreamReader &doc, CategoryItem *parent, bool parseSubText)
 {
     Item *item=nullptr;
