@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2018 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -29,7 +29,6 @@
 #include <QList>
 #include <QUrl>
 
-class QPushButton;
 class LineEdit;
 class QTreeWidget;
 class NetworkJob;
@@ -68,6 +67,8 @@ protected:
     void cancel();
     void cancelImage();
     void addPodcast(const QString &title, const QUrl &url, const QUrl &image, const QString &description, const QString &webPage, QTreeWidgetItem *p);
+    void addCategory(const OpmlParser::Category &cat, QTreeWidgetItem *p);
+    void addPodcast(const OpmlParser::Podcast &pod, QTreeWidgetItem *p);
 
 private Q_SLOTS:
     void selectionChanged();
@@ -129,8 +130,6 @@ private Q_SLOTS:
 
 private:
     void parseResonse(QIODevice *dev) override;
-    void addCategory(const OpmlParser::Category &cat, QTreeWidgetItem *p);
-    void addPodcast(const OpmlParser::Podcast &pod, QTreeWidgetItem *p);
 
 private:
     bool loaded;
@@ -148,13 +147,14 @@ public:
 
 private:
     void parseResonse(QIODevice *dev) override;
+    void parse(QIODevice *dev);
 
 private Q_SLOTS:
     void loadUrl();
+    void openPath();
 
 protected:
     LineEdit *urlEntry;
-    QPushButton *loadButton;
     QUrl currentUrl;
 };
 
