@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2014 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -22,90 +22,69 @@
  */
 
 #include "soundcloudservice.h"
+#include "gui/apikeys.h"
 #include "network/networkaccessmanager.h"
-#include "models/onlineservicesmodel.h"
-#include "models/musiclibraryitemsong.h"
-#include "config.h"
-#include <QCoreApplication>
+#include "mpd-interface/mpdconnection.h"
+#include "support/utils.h"
+#include "support/monoicon.h"
 #include <QUrl>
-#if QT_VERSION >= 0x050000
 #include <QUrlQuery>
 #include <QJsonDocument>
-#else
-#include "qjson/parser.h"
-#endif
 
-const QLatin1String SoundCloudService::constName("SoundCloud");
-QString SoundCloudService::iconFile;
-static const QString constApiKey=QLatin1String("0cb23dce473528973ce74815bd36a334");
-static const QString constUrl=QLatin1String("https://api.soundcloud.com/tracks");
+static const QLatin1String constName("soundcloud");
+static const QLatin1String constUrl("https://api.soundcloud.com/tracks");
 
-SoundCloudService::SoundCloudService(MusicModel *m)
-    : OnlineService(m, constName)
-    , job(0)
+SoundCloudService::SoundCloudService(QObject *p)
+    : OnlineSearchService(p)
 {
-    if (iconFile.isEmpty()) {
-        iconFile=QString(CANTATA_SYS_ICONS_DIR+"soundcloud.png");
-    }
-    setUseArtistImages(false);
-    setUseAlbumImages(false);
+    icn=MonoIcon::icon(FontAwesome::soundcloud, Utils::monoIconColor());
 }
 
-Song SoundCloudService::fixPath(const Song &orig, bool) const
+QString SoundCloudService::name() const
 {
-    Song s(orig);
-    s.setIsFromOnlineService(constName);
-    s.album=constName;
-    return encode(s);
+    return constName;
 }
 
-void SoundCloudService::clear()
+QString SoundCloudService::title() const
 {
-    cancelAll();
-    ::OnlineService::clear();
+    return QLatin1String("SoundCloud");
 }
 
-void SoundCloudService::setSearch(const QString &searchTerm)
+QString SoundCloudService::descr() const
 {
-    if (searchTerm==currentSearch) {
+    return tr("Search for tracks from soundcloud.com");
+}
+
+void SoundCloudService::search(const QString &key, const QString &value)
+{
+    Q_UNUSED(key);
+
+    if (value==currentValue) {
         return;
     }
 
     clear();
+    cancel();
 
-    currentSearch=searchTerm;
+    currentValue=value;
 
-    if (currentSearch.isEmpty()) {
+    if (currentValue.isEmpty()) {
         return;
     }
 
     QUrl searchUrl(constUrl);
-    #if QT_VERSION < 0x050000
-    QUrl &query=searchUrl;
-    #else
     QUrlQuery query;
-    #endif
-    query.addQueryItem("client_id", constApiKey);
-    query.addQueryItem("q", searchTerm);
-    #if QT_VERSION >= 0x050000
+    ApiKeys::self()->addKey(query, ApiKeys::SoundCloud);
+    query.addQueryItem("q", currentValue);
+    query.addQueryItem("limit", QString::number(200));
     searchUrl.setQuery(query);
-    #endif
 
     QNetworkRequest req(searchUrl);
     req.setRawHeader("Accept", "application/json");
     job=NetworkAccessManager::self()->get(req);
     connect(job, SIGNAL(finished()), this, SLOT(jobFinished()));
-    emitUpdated();
-    setBusy(true);
-}
-
-void SoundCloudService::cancelAll()
-{
-    if (job) {
-        job->cancelAndDelete();
-        job=0;
-    }
-    setBusy(false);
+    emit searching();
+    emit dataChanged(QModelIndex(), QModelIndex());
 }
 
 void SoundCloudService::jobFinished()
@@ -116,52 +95,43 @@ void SoundCloudService::jobFinished()
     }
 
     j->deleteLater();
+    QList<Song> songs;
 
     if (j->ok()) {
-        #if QT_VERSION >= 0x050000
         QVariant result=QJsonDocument::fromJson(j->readAll()).toVariant();
-        #else
-        QVariant result = QJson::Parser().parse(j->readAll());
-        #endif
         if (result.isValid()) {
             QVariantList list = result.toList();
-            foreach(const QVariant &item, list) {
+            for (const QVariant &item: list) {
                 QVariantMap details=item.toMap();
                 if (details["title"].toString().isEmpty()) {
                     continue;
                 }
                 Song song;
                 QUrl url = details["stream_url"].toUrl();
-                #if QT_VERSION < 0x050000
-                QUrl &query=url;
-                #else
                 QUrlQuery query;
-                #endif
-                query.addQueryItem("client_id", constApiKey);
-                #if QT_VERSION >= 0x050000
+                ApiKeys::self()->addKey(query, ApiKeys::SoundCloud);
                 url.setQuery(query);
-                #endif
                 // MPD does not seem to support https :-(
-                if (QLatin1String("https")==url.scheme()) {
+                if (QLatin1String("https")==url.scheme() && !MPDConnection::self()->urlHandlers().contains(QLatin1String("https"))) {
                     url.setScheme(QLatin1String("http"));
                 }
                 song.file=url.toString();
                 // We don't have a real artist name, but username is the most similar thing we have
                 song.artist=details["user"].toMap()["username"].toString();
                 song.title=details["title"].toString();
-                song.genre=details["genre"].toString();
+                song.genres[0]=details["genre"].toString();
                 song.year=details["release_year"].toInt();
                 song.time=details["duration"].toUInt()/1000;
-                if (!update) {
-                    update=new OnlineServiceMusicRoot();
-                }
                 song.fillEmptyFields();
-                update->append(new MusicLibraryItemSong(song, update));
+                songs.append(song);
             }
         }
+    } else {
+        ApiKeys::self()->isLimitReached(j->actualJob(), ApiKeys::SoundCloud);
     }
-
-    loaded=true;
-    job=0;
-    applyUpdate();
+    results(songs);
+    job=nullptr;
+    emit dataChanged(QModelIndex(), QModelIndex());
 }
+
+#include "moc_soundcloudservice.cpp"
