@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2018 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -32,6 +32,7 @@
 #include <QSortFilterProxyModel>
 #include <QSpinBox>
 #include <QStyle>
+#include <algorithm>
 
 #define REMOVE(w) \
     w->setVisible(false); \
@@ -154,6 +155,8 @@ PlaylistRulesDialog::PlaylistRulesDialog(QWidget *parent, RulesPlaylists *m)
     connect(rulesList, SIGNAL(itemsSelected(bool)), SLOT(controlButtons()));
     connect(nameText, SIGNAL(textChanged(const QString &)), SLOT(enableOkButton()));
     connect(aboutLabel, SIGNAL(leftClickedUrl()), this, SLOT(showAbout()));
+    connect(ratingFrom, SIGNAL(valueChanged(int)), SLOT(ratingChanged(int)));
+    connect(ratingTo, SIGNAL(valueChanged(int)), SLOT(ratingChanged(int)));
     if (rules->isDynamic()) {
         connect(rules, SIGNAL(saved(bool)), SLOT(saved(bool)));
     }
@@ -236,6 +239,8 @@ void PlaylistRulesDialog::edit(const QString &name)
     origName=name;
     ratingFrom->setValue(e.ratingFrom);
     ratingTo->setValue(e.ratingTo);
+    includeUnrated->setChecked(e.includeUnrated);
+    ratingChanged(0);
     minDuration->setValue(e.minDuration);
     maxDuration->setValue(e.maxDuration);
     numTracks->setValue(e.numTracks);
@@ -337,7 +342,7 @@ void PlaylistRulesDialog::remove()
     for (const QModelIndex &i: items) {
         rows.append(proxy->mapToSource(i).row());
     }
-    qSort(rows);
+    std::sort(rows.begin(), rows.end());
     while (rows.count()) {
         model->removeRow(rows.takeLast());
     }
@@ -390,6 +395,12 @@ void PlaylistRulesDialog::setOrder()
     }
 }
 
+void PlaylistRulesDialog::ratingChanged(int value)
+{
+    Q_UNUSED(value);
+    includeUnrated->setEnabled(ratingFrom->value()>0 || ratingTo->value()>0);
+}
+
 void PlaylistRulesDialog::saved(bool s)
 {
     if (s) {
@@ -424,6 +435,7 @@ bool PlaylistRulesDialog::save()
     int to=ratingTo->value();
     entry.ratingFrom=qMin(from, to);
     entry.ratingTo=qMax(from, to);
+    entry.includeUnrated=includeUnrated->isChecked();
     if (order) {
         entry.order=(RulesPlaylists::Order)order->currentData().toInt();
         entry.orderAscending=0==orderAscending->currentIndex();
