@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2018 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -31,6 +31,7 @@
 #include "support/messagebox.h"
 #include "gui/stdactions.h"
 #include "models/mpdlibrarymodel.h"
+#include <algorithm>
 
 SmartPlaylistsPage::SmartPlaylistsPage(QWidget *p)
     : SinglePageWidget(p)
@@ -169,7 +170,7 @@ void SmartPlaylistsPage::searchResponse(const QString &id, const QList<Song> &so
     if (command.includeRules.isEmpty()) {
         if (command.songs.isEmpty()) {
             command.clear();
-            MessageBox::error(this, tr("Failed to locate any matching songs"));
+            emit error(tr("Failed to locate any matching songs"));
             return;
         }
         if (command.excludeRules.isEmpty()) {
@@ -201,12 +202,12 @@ void SmartPlaylistsPage::filterCommand()
         command.songs.subtract(toRemove);
         if (command.songs.isEmpty()) {
             command.clear();
-            MessageBox::error(this, tr("Failed to locate any matching songs"));
+            emit error(tr("Failed to locate any matching songs"));
             return;
         }
     }
 
-    if (command.filterRating || command.fetchRatings) {
+    if (command.filterRating || command.fetchRatings || command.includeUnrated) {
         if (command.toCheck.isEmpty()) {
             for (const auto &s: command.songs) {
                 command.toCheck.append(s.file);
@@ -228,7 +229,8 @@ void SmartPlaylistsPage::rating(const QString &file, quint8 val)
     for (auto &s: command.songs) {
         if (s.file==file) {
             s.rating=val;
-            if (command.filterRating && (val<command.ratingFrom || val>command.ratingTo)) {
+            if (command.filterRating && (val<command.ratingFrom || val>command.ratingTo) &&
+                !(command.includeUnrated && val==0)) {
                 command.songs.remove(s);
             }
             break;
@@ -263,8 +265,8 @@ static bool artistSort(const Song &s1, const Song &s2)
 
 static bool albumArtistSort(const Song &s1, const Song &s2)
 {
-    const QString v1=s1.hasAlbumArtistSort() ? s1.albumArtistSort() : s1.artistOrComposer();
-    const QString v2=s2.hasAlbumArtistSort() ? s2.albumArtistSort() : s2.artistOrComposer();
+    const QString v1=s1.hasAlbumArtistSort() ? s1.albumArtistSort() : s1.albumArtistOrComposer();
+    const QString v2=s2.hasAlbumArtistSort() ? s2.albumArtistSort() : s2.albumArtistOrComposer();
     int c=v1.localeAwareCompare(v2);
     return sortAscending ? (c<0 || (c==0 && s1<s2)) : (c>0 || (c==0 && s1<s2));
 }
@@ -312,7 +314,7 @@ void SmartPlaylistsPage::addSongsToPlayQueue()
 {
     if (command.songs.isEmpty()) {
         command.clear();
-        MessageBox::error(this, tr("Failed to locate any matching songs"));
+        emit error(tr("Failed to locate any matching songs"));
         return;
     }
 
@@ -322,31 +324,31 @@ void SmartPlaylistsPage::addSongsToPlayQueue()
     sortAscending = command.orderAscending;
     switch(command.order) {
     case RulesPlaylists::Order_AlbumArtist:
-        qSort(songs.begin(), songs.end(), albumArtistSort);
+        std::sort(songs.begin(), songs.end(), albumArtistSort);
         break;
     case RulesPlaylists::Order_Artist:
-        qSort(songs.begin(), songs.end(), artistSort);
+        std::sort(songs.begin(), songs.end(), artistSort);
         break;
     case RulesPlaylists::Order_Album:
-        qSort(songs.begin(), songs.end(), albumSort);
+        std::sort(songs.begin(), songs.end(), albumSort);
         break;
     case RulesPlaylists::Order_Composer:
-        qSort(songs.begin(), songs.end(), composerSort);
+        std::sort(songs.begin(), songs.end(), composerSort);
         break;
     case RulesPlaylists::Order_Date:
-        qSort(songs.begin(), songs.end(), dateSort);
+        std::sort(songs.begin(), songs.end(), dateSort);
         break;
     case RulesPlaylists::Order_Genre:
-        qSort(songs.begin(), songs.end(), genreSort);
+        std::sort(songs.begin(), songs.end(), genreSort);
         break;
     case RulesPlaylists::Order_Rating:
-        qSort(songs.begin(), songs.end(), ratingSort);
+        std::sort(songs.begin(), songs.end(), ratingSort);
         break;
     case RulesPlaylists::Order_Title:
-        qSort(songs.begin(), songs.end(), titleSort);
+        std::sort(songs.begin(), songs.end(), titleSort);
         break;
     case RulesPlaylists::Order_Age:
-        qSort(songs.begin(), songs.end(), ageSort);
+        std::sort(songs.begin(), songs.end(), ageSort);
         break;
     default:
     case RulesPlaylists::Order_Random:
@@ -424,15 +426,19 @@ void SmartPlaylistsPage::addSelectionToPlaylist(const QString &name, int action,
                         mpdGenres = MpdLibraryModel::self()->getGenres();
                     }
                     for (const QString &g: mpdGenres) {
-                        if (g.startsWith(find)) {
+                        if (g.startsWith(find, Qt::CaseInsensitive)) {
                             genres.append(g);
                         }
                     }
                 }
+                if (genres.isEmpty()) {
+                    // No genres matching pattern - add dummy genre, so that no tracks will be found
+                    genres.append("XXXXXXXXX");
+                }
             } else if (RulesPlaylists::constArtistKey==rIt.key() || RulesPlaylists::constAlbumKey==rIt.key() ||
                        RulesPlaylists::constAlbumArtistKey==rIt.key() || RulesPlaylists::constComposerKey==rIt.key() ||
                        RulesPlaylists::constCommentKey==rIt.key() || RulesPlaylists::constTitleKey==rIt.key() ||
-                       RulesPlaylists::constArtistKey==rIt.key() || RulesPlaylists::constGenreKey==rIt.key() ||
+                       RulesPlaylists::constSimilarArtistsKey==rIt.key() || RulesPlaylists::constGenreKey==rIt.key() ||
                        RulesPlaylists::constFileKey==rIt.key()) {
                 baseRule += " " + rIt.key() + " " + MPDConnection::encodeName(rIt.value());
             } else if (RulesPlaylists::constExactKey==rIt.key()) {
