@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2018 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -47,7 +47,7 @@ void AlbumScanner::start()
 {
     if (!proc) {
         proc=new QProcess(this);
-        proc->setReadChannelMode(QProcess::MergedChannels);
+        proc->setProcessChannelMode(QProcess::MergedChannels);
         proc->setReadChannel(QProcess::StandardOutput);
         connect(proc, SIGNAL(finished(int)), this, SLOT(procFinished()));
         connect(proc, SIGNAL(readyReadStandardOutput()), this, SLOT(read()));
