@@ -35,6 +35,7 @@
 #include <QDesktopWidget>
 #include <QEventLoop>
 #include <QStandardPaths>
+#include <QSystemTrayIcon>
 #include <QSet>
 #include <QUrl>
 #ifndef _MSC_VER 
@@ -782,11 +783,11 @@ QString Utils::cacheDir(const QString &sub, bool create)
 QString Utils::systemDir(const QString &sub)
 {
     #if defined Q_OS_WIN
-    return fixPath(QCoreApplication::applicationDirPath())+(sub.isEmpty() ? QString() : (sub+constDirSep));
+    return fixPath(QCoreApplication::applicationDirPath()+constDirSep+(sub.isEmpty() ? QString() : (sub+constDirSep)));
     #elif defined Q_OS_MAC
-    return fixPath(QCoreApplication::applicationDirPath())+QLatin1String("../Resources/")+(sub.isEmpty() ? QString() : (sub+constDirSep));
+    return fixPath(QCoreApplication::applicationDirPath()+QLatin1String("/../Resources/")+(sub.isEmpty() ? QString() : (sub+constDirSep)));
     #else
-    return fixPath(QString(SHARE_INSTALL_PREFIX"/")+QCoreApplication::applicationName()+constDirSep+(sub.isEmpty() ? QString() : sub));
+    return fixPath(QString(SHARE_INSTALL_PREFIX"/")+QCoreApplication::applicationName()+constDirSep+(sub.isEmpty() ? QString() : (sub+constDirSep)));
     #endif
 }
 
@@ -802,7 +803,7 @@ QString Utils::helper(const QString &app)
     if (QFile::exists(local)) {
         return local;
     }
-    return QString(INSTALL_PREFIX "/" LINUX_LIB_DIR "/")+QCoreApplication::applicationName()+constDirSep+app;
+    return fixPath(QString(INSTALL_PREFIX "/" LINUX_LIB_DIR "/")+QCoreApplication::applicationName()+constDirSep)+app;
     #endif
 }
 
@@ -982,9 +983,11 @@ bool Utils::useSystemTray()
     #elif defined Q_OS_WIN
     return true;
     #elif QT_QTDBUS_FOUND
-    return Gnome==currentDe() ? QDBusConnection::sessionBus().interface()->isServiceRegistered("org.kde.StatusNotifierWatcher") : true;
+    return (Gnome==currentDe() || Unity==currentDe())
+            ? QDBusConnection::sessionBus().interface()->isServiceRegistered("org.kde.StatusNotifierWatcher")
+            : QSystemTrayIcon::isSystemTrayAvailable();
     #else
-    return Gnome!=currentDe();
+    return Gnome!=currentDe() && Unity!=currentDe() && QSystemTrayIcon::isSystemTrayAvailable();
     #endif
 }
 
