@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2014 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -24,15 +24,14 @@
 #ifndef TAGS_H
 #define TAGS_H
 
-#include "mpd/song.h"
+#include "mpd-interface/song.h"
 #include "support/utils.h"
-#include "support/localize.h"
 #include "config.h"
 #include <QMap>
 #include <QImage>
 #include <QMetaType>
 
-#if defined ENABLE_EXTERNAL_TAGS && !defined CANTATA_TAG_SERVER
+#ifndef CANTATA_TAG_SERVER
 #include "taghelperiface.h"
 #endif
 
@@ -67,7 +66,7 @@ namespace Tags
     };
 
     void enableDebug();
-    #if defined ENABLE_EXTERNAL_TAGS && !defined CANTATA_TAG_SERVER
+    #ifndef CANTATA_TAG_SERVER
     inline void init() { TagHelperIface::self(); }
     inline void stop() { TagHelperIface::self()->stop(); }
     inline Song read(const QString &fileName) { return TagHelperIface::self()->read(fileName); }
@@ -80,6 +79,8 @@ namespace Tags
     inline Update updateReplaygain(const QString &fileName, const ReplayGain &rg) { return (Update)TagHelperIface::self()->updateReplaygain(fileName, rg); }
     inline Update embedImage(const QString &fileName, const QByteArray &cover) { return (Update)TagHelperIface::self()->embedImage(fileName, cover); }
     inline QString oggMimeType(const QString &fileName) { return TagHelperIface::self()->oggMimeType(fileName); }
+    inline int readRating(const QString &fileName) { return TagHelperIface::self()->readRating(fileName); }
+    inline Update updateRating(const QString &fileName, int rating) { return (Update)TagHelperIface::self()->updateRating(fileName, rating); }
     inline QMap<QString, QString> readAll(const QString &fileName) { return TagHelperIface::self()->readAll(fileName); }
     #else
     inline void init() { }
@@ -94,12 +95,13 @@ namespace Tags
     extern Update updateReplaygain(const QString &fileName, const ReplayGain &rg);
     extern Update embedImage(const QString &fileName, const QByteArray &cover);
     extern QString oggMimeType(const QString &fileName);
+    extern int readRating(const QString &fileName);
+    extern Update updateRating(const QString &fileName, int rating);
     extern QMap<QString, QString> readAll(const QString &fileName);
     #endif
     extern QString id3Genre(int id);
 }
 
-#ifdef ENABLE_EXTERNAL_TAGS
 Q_DECLARE_METATYPE(Tags::ReplayGain)
 
 inline QDataStream & operator<<(QDataStream &stream, const Tags::ReplayGain &rg)
@@ -113,6 +115,5 @@ inline QDataStream & operator>>(QDataStream &stream, Tags::ReplayGain &rg)
     stream >> rg.trackGain >> rg.albumGain >> rg.trackPeak >> rg.albumPeak;
     return stream;
 }
-#endif
 
 #endif
