@@ -23,12 +23,12 @@
 
 #include "genrecombo.h"
 #include "toolbutton.h"
-#include "support/localize.h"
 #include "support/actioncollection.h"
 #include "support/action.h"
 #include <QEvent>
+#include <algorithm>
 
-static Action *action=0;
+static Action *action=nullptr;
 
 GenreCombo::GenreCombo(QWidget *p)
      : ComboBox(p)
@@ -38,7 +38,7 @@ GenreCombo::GenreCombo(QWidget *p)
     setEditable(false);
     setFocusPolicy(Qt::NoFocus);
     if (!action) {
-        action=ActionCollection::get()->createAction("genrefilter", i18n("Filter On Genre"), 0);
+        action=ActionCollection::get()->createAction("genrefilter", tr("Filter On Genre"), nullptr);
         action->setShortcut(Qt::ControlModifier+Qt::Key_G);
     }
     addAction(action);
@@ -59,8 +59,8 @@ void GenreCombo::update(const QSet<QString> &g)
 
     genres=mg;
     QStringList entries=g.toList();
-    qSort(entries);
-    entries.prepend(i18n("All Genres"));
+    std::sort(entries.begin(), entries.end());
+    entries.prepend(tr("All Genres"));
 
     if (count()==entries.count()) {
         bool noChange=true;
@@ -124,3 +124,5 @@ bool GenreCombo::event(QEvent *event)
     }
     return ComboBox::event(event);
 }
+
+#include "moc_genrecombo.cpp"
