@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2018 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -24,7 +24,9 @@
 #include "itemview.h"
 #include "groupedview.h"
 #include "tableview.h"
+#ifdef ENABLE_CATEGORIZED_VIEW
 #include "categorizedview.h"
+#endif
 #include "messageoverlay.h"
 #include "models/roles.h"
 #include "gui/covers.h"
@@ -42,6 +44,7 @@
 #include "support/actioncollection.h"
 #include "support/configuration.h"
 #include "support/flattoolbutton.h"
+#include "support/monoicon.h"
 #include <QStyleOption>
 #include <QStyle>
 #include <QPainter>
@@ -147,8 +150,10 @@ static int zoomedSize(QListView *view, int size) {
     return view
             ? qobject_cast<ListView *>(view)
               ? static_cast<ListView *>(view)->zoom()*size
+            #ifdef ENABLE_CATEGORIZED_VIEW
               : qobject_cast<CategorizedView *>(view)
                 ? static_cast<CategorizedView *>(view)->zoom()*size
+            #endif
                 : size
             : size;
 }
@@ -157,8 +162,10 @@ static QSize zoomedSize(QListView *view, QSize size) {
     return view
             ? qobject_cast<ListView *>(view)
               ? static_cast<ListView *>(view)->zoom()*size
+            #ifdef ENABLE_CATEGORIZED_VIEW
               : qobject_cast<CategorizedView *>(view)
                 ? static_cast<CategorizedView *>(view)->zoom()*size
+            #endif
                 : size
             : size;
 }
@@ -172,7 +179,11 @@ public:
         #ifdef RESPONSIVE_LAYOUT
         , viewGap(Utils::scaleForDpi(8))
         #endif
+        #ifdef ENABLE_CATEGORIZED_VIEW
         , isCategorizedView(v && qobject_cast<CategorizedView *>(v))
+        #else
+        , isCategorizedView(false)
+        #endif
     {
     }
 
@@ -203,7 +214,9 @@ public:
         int viewCount = view->model() ? view->model()->rowCount(view->rootIndex()) : -1;
         int numItems = viewWidth/iconWidth;
         if (numItems>1 && viewCount>1 && (viewCount+1)>numItems) {
-            iconWidth=qMax(iconWidth-1, (int)(viewWidth/numItems)-3);
+            iconWidth = qMax(iconWidth-1, (int)(viewWidth/numItems)-1);
+        } else if (numItems==1) {
+            iconWidth = viewWidth;
         }
         return iconWidth;
     }
@@ -380,7 +393,10 @@ public:
 
         QRect textRect;
         QTextOption textOpt(AP_VTop==actionPos ? Qt::AlignHCenter|Qt::AlignVCenter : Qt::AlignVCenter);
-
+        QVariant col = index.data(Cantata::Role_TextColor);
+        if (col.isValid()) {
+            textColor = col.value<QColor>();
+        }
         textOpt.setWrapMode(QTextOption::NoWrap);
         if (oneLine) {
             textRect=QRect(r.x(), r.y()+((r.height()-textHeight)/2), r.width(), textHeight);
@@ -566,6 +582,10 @@ public:
             }
         }
 
+        QVariant col = index.data(Cantata::Role_TextColor);
+        if (col.isValid()) {
+            textColor = col.value<QColor>();
+        }
         if (text.count()>0) {
             QFont textFont(QApplication::font());
             QFontMetrics textMetrics(textFont);
@@ -580,9 +600,9 @@ public:
             painter->drawText(textRect, str, textOpt);
 
             if (text.count()>1) {
-                int mainWidth=textMetrics.width(str);
+                int mainWidth=textMetrics.horizontalAdvance(str);
                 text.takeFirst();
-                str=text.join(QString(" – "));
+                str=text.join(Song::constSep);
                 textRect=QRect(r.x()+(mainWidth+8), r.y()+((r.height()-textHeight)/2), r.width()-(mainWidth+8), textHeight);
                 if (textRect.width()>4) {
                     str = textMetrics.elidedText(str, Qt::ElideRight, textRect.width(), QPalette::WindowText);
@@ -652,7 +672,9 @@ QString ItemView::modeStr(Mode m)
     case Mode_IconTop:      return QLatin1String("icontop");
     case Mode_GroupedTree:  return QLatin1String("grouped");
     case Mode_Table:        return QLatin1String("table");
+    #ifdef ENABLE_CATEGORIZED_VIEW
     case Mode_Categorized:  return QLatin1String("categorized");
+    #endif
     }
 }
 
@@ -678,7 +700,9 @@ ItemView::ItemView(QWidget *p)
     , mode(Mode_SimpleTree)
     , groupedView(nullptr)
     , tableView(nullptr)
+    #ifdef ENABLE_CATEGORIZED_VIEW
     , categorizedView(nullptr)
+    #endif
     , spinner(nullptr)
     , msgOverlay(nullptr)
     , performedSearch(false)
@@ -829,6 +853,7 @@ void ItemView::allowTableView(TableView *v)
 
 void ItemView::allowCategorized()
 {
+    #ifdef ENABLE_CATEGORIZED_VIEW
     if (!categorizedView) {
         categorizedView=new CategorizedView(stackedWidget);
         categorizedView->setParent(stackedWidget);
@@ -847,6 +872,7 @@ void ItemView::allowCategorized()
         #endif
         categorizedView->setItemDelegate(new ListDelegate(categorizedView, categorizedView));
     }
+    #endif
 }
 
 void ItemView::addAction(QAction *act)
@@ -859,9 +885,11 @@ void ItemView::addAction(QAction *act)
     if (tableView) {
         tableView->addAction(act);
     }
+    #ifdef ENABLE_CATEGORIZED_VIEW
     if (categorizedView) {
         categorizedView->addAction(act);
     }
+    #endif
 }
 
 void ItemView::addSeparator()
@@ -874,7 +902,11 @@ void ItemView::addSeparator()
 void ItemView::setMode(Mode m)
 {
     initialised=true;
-    if (m<0 || m>=Mode_Count || (Mode_GroupedTree==m && !groupedView) || (Mode_Table==m && !tableView) || (Mode_Categorized==m && !categorizedView)) {
+    if (m<0 || m>=Mode_Count || (Mode_GroupedTree==m && !groupedView) || (Mode_Table==m && !tableView)
+        #ifdef ENABLE_CATEGORIZED_VIEW
+        || (Mode_Categorized==m && !categorizedView)
+        #endif
+        ) {
         m=Mode_SimpleTree;
     }
 
@@ -905,9 +937,11 @@ void ItemView::setMode(Mode m)
             tableView->saveHeader();
             tableView->setModel(nullptr);
         }
+        #ifdef ENABLE_CATEGORIZED_VIEW
         if (categorizedView) {
             categorizedView->setModel(nullptr);
         }
+        #endif
         treeView->setModel(itemModel);
         treeView->setHidden(false);
         static_cast<TreeDelegate *>(treeView->itemDelegate())->setSimple(Mode_SimpleTree==mode || Mode_BasicTree==mode);
@@ -923,9 +957,11 @@ void ItemView::setMode(Mode m)
             tableView->saveHeader();
             tableView->setModel(nullptr);
         }
+        #ifdef ENABLE_CATEGORIZED_VIEW
         if (categorizedView) {
             categorizedView->setModel(nullptr);
         }
+        #endif
         groupedView->setHidden(false);
         treeView->setHidden(true);
         groupedView->setModel(itemModel);
@@ -940,9 +976,11 @@ void ItemView::setMode(Mode m)
         if (groupedView) {
             groupedView->setModel(nullptr);
         }
+        #ifdef ENABLE_CATEGORIZED_VIEW
         if (categorizedView) {
             categorizedView->setModel(nullptr);
         }
+        #endif
         tableView->setHidden(false);
         treeView->setHidden(true);
         tableView->setModel(itemModel);
@@ -952,6 +990,7 @@ void ItemView::setMode(Mode m)
         }
         tableView->resize(w, tableView->height());
         stackIndex=tableView->property(constPageProp).toInt();
+    #ifdef ENABLE_CATEGORIZED_VIEW
     } else if (Mode_Categorized==mode) {
         //int w=view()->width();
         treeView->setModel(nullptr);
@@ -967,6 +1006,7 @@ void ItemView::setMode(Mode m)
         categorizedView->setModel(itemModel);
         stackIndex=categorizedView->property(constPageProp).toInt();
         categorizedView->setGridSize(zoomedSize(listView, iconGridSize));
+    #endif
     } else {
         stackIndex=1;
         treeView->setModel(nullptr);
@@ -977,9 +1017,11 @@ void ItemView::setMode(Mode m)
             tableView->saveHeader();
             tableView->setModel(nullptr);
         }
+        #ifdef ENABLE_CATEGORIZED_VIEW
         if (categorizedView) {
             categorizedView->setModel(nullptr);
         }
+        #endif
         listView->setModel(itemModel);
         goToTop();
         if (Mode_IconTop!=mode) {
@@ -1019,9 +1061,12 @@ QModelIndexList ItemView::selectedIndexes(bool sorted) const
         return groupedView->selectedIndexes(sorted);
     } else if (Mode_Table==mode) {
         return tableView->selectedIndexes(sorted);
-    } else if (Mode_Categorized==mode) {
+    }
+    #ifdef ENABLE_CATEGORIZED_VIEW
+    else if (Mode_Categorized==mode) {
         return categorizedView->selectedIndexes(sorted);
     }
+    #endif
     return listView->selectedIndexes(sorted);
 }
 
@@ -1034,13 +1079,16 @@ void ItemView::goToTop()
             static_cast<ProxyModel *>(itemModel)->setRootIndex(QModelIndex());
         }
         listView->setRootIndex(QModelIndex());
-    } else if (Mode_Categorized==mode) {
+    }
+    #ifdef ENABLE_CATEGORIZED_VIEW
+    else if (Mode_Categorized==mode) {
         categorizedView->setRootIndex(QModelIndex());
         categorizedView->setPlain(false);
         // Setting grid size causes categorizedview to re-lyout items. If we don't do this
         // then items are all messed up!
         categorizedView->setGridSizeOwn(categorizedView->gridSize());
     }
+    #endif
     setTitle();
     emit rootIndexSet(QModelIndex());
 }
@@ -1059,9 +1107,11 @@ void ItemView::setEnabled(bool en)
     if (listView) {
         listView->setEnabled(en);
     }
+    #ifdef ENABLE_CATEGORIZED_VIEW
     if (categorizedView) {
         categorizedView->setEnabled(en);
     }
+    #endif
 }
 
 void ItemView::setInfoText(const QString &info)
@@ -1074,9 +1124,11 @@ void ItemView::setInfoText(const QString &info)
     if (tableView) {
         tableView->setInfoText(info);
     }
+    #ifdef ENABLE_CATEGORIZED_VIEW
     if (categorizedView) {
         categorizedView->setInfoText(info);
     }
+    #endif
 }
 
 void ItemView::setLevel(int l, bool haveChildren)
@@ -1124,9 +1176,13 @@ QAbstractItemView * ItemView::view() const
         return groupedView;
     } else if(Mode_Table==mode) {
         return tableView;
-    } else if(Mode_Categorized==mode) {
+    }
+    #ifdef ENABLE_CATEGORIZED_VIEW
+    else if(Mode_Categorized==mode) {
         return categorizedView;
-    } else {
+    }
+    #endif
+    else {
         return listView;
     }
 }
@@ -1192,9 +1248,11 @@ void ItemView::setAcceptDrops(bool v)
     if (tableView) {
         tableView->setAcceptDrops(v);
     }
+    #ifdef ENABLE_CATEGORIZED_VIEW
     if (categorizedView) {
         categorizedView->setAcceptDrops(v);
     }
+    #endif
 }
 
 void ItemView::setDragDropOverwriteMode(bool v)
@@ -1207,9 +1265,11 @@ void ItemView::setDragDropOverwriteMode(bool v)
     if (tableView) {
         tableView->setDragDropOverwriteMode(v);
     }
+    #ifdef ENABLE_CATEGORIZED_VIEW
     if (categorizedView) {
         categorizedView->setDragDropOverwriteMode(v);
     }
+    #endif
 }
 
 void ItemView::setDragDropMode(QAbstractItemView::DragDropMode v)
@@ -1222,9 +1282,11 @@ void ItemView::setDragDropMode(QAbstractItemView::DragDropMode v)
     if (tableView) {
         tableView->setDragDropMode(v);
     }
+    #ifdef ENABLE_CATEGORIZED_VIEW
     if (categorizedView) {
         categorizedView->setDragDropMode(v);
     }
+    #endif
 }
 
 void ItemView::update()
@@ -1258,6 +1320,7 @@ void ItemView::setDeleteAction(QAction *act)
             static_cast<KeyEventHandler *>(tableView->filter())->setDeleteAction(act);
         }
     }
+    #ifdef ENABLE_CATEGORIZED_VIEW
     if (categorizedView) {
         if (!categorizedView->filter() || !qobject_cast<KeyEventHandler *>(categorizedView->filter())) {
             categorizedView->installEventFilter(new KeyEventHandler(categorizedView, act));
@@ -1265,6 +1328,7 @@ void ItemView::setDeleteAction(QAction *act)
             static_cast<KeyEventHandler *>(categorizedView->filter())->setDeleteAction(act);
         }
     }
+    #endif
 }
 
 void ItemView::showIndex(const QModelIndex &idx, bool scrollTo)
@@ -1279,9 +1343,13 @@ void ItemView::showIndex(const QModelIndex &idx, bool scrollTo)
         if (scrollTo) {
             v->scrollTo(idx, QAbstractItemView::PositionAtTop);
         }
-    } else if (Mode_Categorized==mode) {
+    }
+    #ifdef ENABLE_CATEGORIZED_VIEW
+    else if (Mode_Categorized==mode) {
         // TODO
-    } else {
+    }
+    #endif
+    else {
         if (idx.parent().isValid()) {
             QList<QModelIndex> indexes;
             QModelIndex i=idx.parent();
@@ -1416,9 +1484,13 @@ void ItemView::setBackgroundImage(const QIcon &icon)
         groupedView->setBackgroundImage(bgndIcon);
     } else if (Mode_Table==mode && tableView) {
         tableView->setBackgroundImage(bgndIcon);
-    } else if (Mode_Categorized==mode && categorizedView) {
+    }
+    #ifdef ENABLE_CATEGORIZED_VIEW
+    else if (Mode_Categorized==mode && categorizedView) {
         categorizedView->setBackgroundImage(bgndIcon);
-    } else if (Mode_List==mode || Mode_IconTop==mode) {
+    }
+    #endif
+    else if (Mode_List==mode || Mode_IconTop==mode) {
         listView->setBackgroundImage(bgndIcon);
     }
 }
@@ -1528,7 +1600,9 @@ void ItemView::backActivated()
         }
         listView->setRootIndex(listView->rootIndex().parent());
         emit rootIndexSet(listView->rootIndex().parent());
-    } else {
+    }
+    #ifdef ENABLE_CATEGORIZED_VIEW
+    else {
         categorizedView->setRootIndex(categorizedView->rootIndex().parent());
         categorizedView->setPlain(false);
         // Setting grid size causes categorizedview to re-lyout items. If we don't do this
@@ -1536,6 +1610,7 @@ void ItemView::backActivated()
         categorizedView->setGridSizeOwn(categorizedView->gridSize());
         emit rootIndexSet(categorizedView->rootIndex().parent());
     }
+    #endif
     setTitle();
 
     if (prevTopIndex.isEmpty()) {
@@ -1552,9 +1627,12 @@ void ItemView::backActivated()
         } else {
             listView->scrollTo(prevTop, QAbstractItemView::PositionAtTop);
         }
-    } else {
+    }
+    #ifdef ENABLE_CATEGORIZED_VIEW
+    else {
         categorizedView->scrollTo(prevTop, QAbstractItemView::PositionAtTop);
     }
+    #endif
 }
 
 void ItemView::setExpanded(const QModelIndex &idx, bool exp)
@@ -1566,7 +1644,11 @@ void ItemView::setExpanded(const QModelIndex &idx, bool exp)
 
 QAction * ItemView::getAction(const QModelIndex &index)
 {
-    QModelIndex idx = Mode_Categorized==mode ? categorizedView->mapFromSource(index) : index;
+    QModelIndex idx =
+    #ifdef ENABLE_CATEGORIZED_VIEW
+        Mode_Categorized==mode ? categorizedView->mapFromSource(index) :
+    #endif
+        index;
     QAbstractItemDelegate *abs=view()->itemDelegate();
     ActionItemDelegate *d=abs ? qobject_cast<ActionItemDelegate *>(abs) : nullptr;
     #ifdef RESPONSIVE_LAYOUT
@@ -1613,6 +1695,7 @@ void ItemView::activateItem(const QModelIndex &index, bool emitRootSet)
         if (!index.parent().isValid()) {
             tableView->setExpanded(index, !tableView->TreeView::isExpanded(index));
         }
+    #ifdef ENABLE_CATEGORIZED_VIEW
     } else if (Mode_Categorized==mode) {
         if (index == categorizedView->rootIndex()) {
             return;
@@ -1620,7 +1703,7 @@ void ItemView::activateItem(const QModelIndex &index, bool emitRootSet)
         if (itemModel->canFetchMore(index)) {
             itemModel->fetchMore(index);
         }
-        QModelIndex fistChild=index.child(0, 0);
+        QModelIndex fistChild=itemModel->index(0, 0, index);
         if (!fistChild.isValid()) {
             return;
         }
@@ -1631,7 +1714,7 @@ void ItemView::activateItem(const QModelIndex &index, bool emitRootSet)
         //}
         prevTopIndex.append(curTop);
         bool haveChildren=itemModel->canFetchMore(fistChild);
-        setLevel(currentLevel+1, haveChildren || fistChild.child(0, 0).isValid());
+        setLevel(currentLevel+1, haveChildren || itemModel->index(0, 0, fistChild).isValid());
         categorizedView->setPlain(!haveChildren);
         categorizedView->setRootIndex(index);
         setTitle();
@@ -1643,11 +1726,12 @@ void ItemView::activateItem(const QModelIndex &index, bool emitRootSet)
             emit rootIndexSet(index);
         }
         categorizedView->scrollToTop();
-    } else if (usingListView() && (index.isValid() && (index.child(0, 0).isValid() || itemModel->canFetchMore(index)) && index!=listView->rootIndex())) {
+    #endif
+    } else if (usingListView() && (index.isValid() && (itemModel->index(0, 0, index).isValid() || itemModel->canFetchMore(index)) && index!=listView->rootIndex())) {
         if (itemModel->canFetchMore(index)) {
             itemModel->fetchMore(index);
         }
-        QModelIndex fistChild=index.child(0, 0);
+        QModelIndex fistChild=itemModel->index(0, 0, index);
         if (!fistChild.isValid()) {
             return;
         }
@@ -1657,7 +1741,7 @@ void ItemView::activateItem(const QModelIndex &index, bool emitRootSet)
             curTop=static_cast<QSortFilterProxyModel *>(listView->model())->mapToSource(curTop);
         }
         prevTopIndex.append(curTop);
-        setLevel(currentLevel+1, itemModel->canFetchMore(fistChild) || fistChild.child(0, 0).isValid());
+        setLevel(currentLevel+1, itemModel->canFetchMore(fistChild) || itemModel->index(0, 0, fistChild).isValid());
         listView->setRootIndex(index);
         setTitle();
 
@@ -1693,18 +1777,24 @@ void ItemView::addTitleButtonClicked()
 {
     if ((Mode_List==mode || Mode_IconTop==mode) && view()->rootIndex().isValid()) {
         emit updateToPlayQueue(view()->rootIndex(), false);
-    } else if (Mode_Categorized==mode && categorizedView->rootIndex().isValid()) {
+    }
+    #ifdef ENABLE_CATEGORIZED_VIEW
+    else if (Mode_Categorized==mode && categorizedView->rootIndex().isValid()) {
         emit updateToPlayQueue(categorizedView->rootIndex(), false);
     }
+    #endif
 }
 
 void ItemView::replaceTitleButtonClicked()
 {
     if ((Mode_List==mode || Mode_IconTop==mode) && view()->rootIndex().isValid()) {
         emit updateToPlayQueue(view()->rootIndex(), true);
-    } else if (Mode_Categorized==mode && categorizedView->rootIndex().isValid()) {
+    }
+    #ifdef ENABLE_CATEGORIZED_VIEW
+    else if (Mode_Categorized==mode && categorizedView->rootIndex().isValid()) {
         emit updateToPlayQueue(categorizedView->rootIndex(), true);
     }
+    #endif
 }
 
 void ItemView::coverLoaded(const Song &song, int size)
@@ -1712,7 +1802,11 @@ void ItemView::coverLoaded(const Song &song, int size)
     Q_UNUSED(song)
 
     if (Mode_BasicTree==mode || Mode_GroupedTree==mode || !isVisible() || (Mode_IconTop==mode && size!=zoomedSize(listView, gridCoverSize)) ||
-        (Mode_IconTop!=mode && Mode_Categorized!=mode && size!=listCoverSize) || (Mode_Categorized==mode && size!=zoomedSize(categorizedView, gridCoverSize))) {
+        (Mode_IconTop!=mode && Mode_Categorized!=mode && size!=listCoverSize)
+        #ifdef ENABLE_CATEGORIZED_VIEW
+        || (Mode_Categorized==mode && size!=zoomedSize(categorizedView, gridCoverSize))
+        #endif
+        ) {
         return;
     }
     view()->viewport()->update();
@@ -1725,12 +1819,15 @@ void ItemView::zoomIn()
             listView->setZoom(listView->zoom()+constZoomStep);
             listView->setGridSize(zoomedSize(listView, iconGridSize));
         }
-    } else if (categorizedView && categorizedView->isVisible()) {
+    }
+    #ifdef ENABLE_CATEGORIZED_VIEW
+    else if (categorizedView && categorizedView->isVisible()) {
         if (categorizedView->zoom()+constZoomStep<=constMaxZoom) {
             categorizedView->setZoom(categorizedView->zoom()+constZoomStep);
             categorizedView->setGridSize(zoomedSize(categorizedView, iconGridSize));
         }
     }
+    #endif
 }
 
 void ItemView::zoomOut()
@@ -1740,12 +1837,15 @@ void ItemView::zoomOut()
             listView->setZoom(listView->zoom()-constZoomStep);
             listView->setGridSize(zoomedSize(listView, iconGridSize));
         }
-    } else if (categorizedView && categorizedView->isVisible()) {
+    }
+    #ifdef ENABLE_CATEGORIZED_VIEW
+    else if (categorizedView && categorizedView->isVisible()) {
         if (categorizedView->zoom()-constZoomStep>=constMinZoom) {
             categorizedView->setZoom(categorizedView->zoom()-constZoomStep);
             categorizedView->setGridSize(zoomedSize(categorizedView, iconGridSize));
         }
     }
+    #endif
 }
 
 void ItemView::delaySearchItems()
