@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2014 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -24,17 +24,18 @@
 #ifndef SONG_DIALOG_H
 #define SONG_DIALOG_H
 
-#include "dialog.h"
-#include "song.h"
+#include "support/dialog.h"
+#include "mpd-interface/song.h"
 
 class SongDialog : public Dialog
 {
+    Q_OBJECT
 public:
     static void enableDebug();
 
     SongDialog(QWidget *parent, const QString &name=QString(), const QSize &defSize=QSize())
         : Dialog(parent, name, defSize) { }
-    virtual ~SongDialog() { }
+    ~SongDialog() override { }
 
 protected:
     bool songsOk(const QList<Song> &songs, const QString &base, bool isMpd);
